function used_spleen(itemid, quantity, usetext)
	local item = get_item_data_by_id(itemid)
	if item and item.name then
		if item.spleen then
			if not usetext:match("bad for your spleen.  That .- would cause it to rupture.<") and not usetext:match("You need to be at least level .- to use that item") then
		-- 		print("used spleen", quantity, printstr(item), usetext)
				if tonumber(item.spleen) then
					increase_daily_counter("spleen", tonumber(item.spleen) * quantity)
				else
					day["unknown spleen"] = "yes"
				end
			end
		end
	else
		day["unknown spleen"] = "yes"
		print("Unknown spleen item, id:", itemid)
	end
end

add_processor("/inv_use.php", function()
	used_spleen(tonumber(params.whichitem), tonumber(params.itemquantity) or 1, text)
end)

add_processor("/multiuse.php", function()
	if not params.whichitem then return end
	used_spleen(tonumber(params.whichitem), tonumber(params.quantity), text)
end)

add_processor("/inventory.php", function()
	if requestpath == "/inv_use.php" then
		used_spleen(tonumber(params.whichitem), 1, text:match([[<div id="effdiv">.-</div>]]))
	end
end)


add_printer("/charpane.php", function()
	if character["use custom kolproxy charpane"] ~= "no" then return end

	if tonumber(api_flag_config().compactchar) == 1 then
		text = text:gsub([[(<hr width=50%%>.-)(</table><hr width=50%%><table align=center cellpadding=1 cellspacing=1>)]], function (a, b)
			local spleentext = ""
			if spleen ~= "0" then
				spleentext = [[<tr><td align=right>Spleen:</td><td align=left><b>]] .. spleen_display_string() .. [[</b></td></tr>]]
			end
			if a:match(">Drunk:<") then
				return a:gsub([[(.-)(<tr><td align=right>Drunk:</td><td align=left><b>[0-9,]-</b></td></tr>)]], function (x, y)
					return x .. y .. spleentext
				end) .. b
			else
				return a .. spleentext .. b
			end
		end)
	else
		text = text:gsub([[^(.-)(<table cellpadding=3 align=center>)]], function (a, b)
			local spleentext = ""
			if spleen ~= "0" then
				local spleen_description = random_choice { "Spleen", "Melancholy", "Moroseness" }
				spleentext = [[<tr><td align=right>]] .. spleen_description .. [[:</td><td><b>]] .. spleen_display_string() .. [[</b></td></tr>]]
			end
			if a:match("<tr><td align=right>[^<]-</td><td><b>[0-9,]-</b></td></tr>") then
				return a:gsub([[(.-)(<tr><td align=right>[^<]-</td><td><b>[0-9,]-</b></td></tr>)]], function (x, y)
					return x .. y .. spleentext
				end) .. b
			else
				return a:gsub("</table>$", function() return spleentext .. "</table>" .. b end)
			end
			return a .. b
		end)
	end
end)

local function get_item_field(itemid, field)
	local item = get_item_data_by_id(itemid)
	if item then
		return tonumber(item[field])
	end
end

-- TODO: warn when using frosty mug, divine champagne flute etc.
-- TODO: warn when drinking from cafes
add_always_warning("/inv_booze.php", function()
	if ascensionstatus() == "Aftercore" or have_skill("Ode to Booze") then
		if not buff("Ode to Booze") then
			return "You do not have Ode to Booze active", "drinking without ode"
		end
		local drunk = get_item_field(tonumber(params.whichitem), "drunkenness")
		if not drunk then
			return "This booze is unknown and could potentially be larger than your remaining turns of Ode to Booze.", "drinking unknown booze", "OK, disable the warning."
		else
			local need_turns = (tonumber(params.quantity) or 1) * drunk
			if buffturns("Ode to Booze") < need_turns then
				return "You do not have enough turns of Ode to Booze active (need " .. need_turns .. ")", "drinking without enough turns of ode to booze"
			end
		end
	end
end)

add_extra_always_warning("/inv_booze.php", function()
	if character["show extra warnings"] ~= "yes" then return end
	local max_safe_drunk = 14
	if have_skill("Liver of Steel") then
		max_safe_drunk = 19
	end

	local safe = false
	local unknown = true
	if tonumber(params.whichitem) then
		local drunk = get_item_field(tonumber(params.whichitem), "drunkenness")
		if drunk then
			unknown = false
			if drunkenness() + drunk * (tonumber(params.quantity) or 1) <= max_safe_drunk then
				safe = true
			end
		end
	end
	
	if unknown then
		return "This booze is unknown and could potentially make you fallen-down drunk.", "overdrinking unknown booze", "OK, disable the warning."
	elseif not safe then
		return "This booze will make you fallen-down drunk.", "overdrinking", "OK, I'm done for today, disable the warning."
	end
end)

local function check_eating_warning(itemid, quantity)
	if not buff("Got Milk") then
		return "You do not have Got Milk active", "eating without milk"
	end
	local full = get_item_field(itemid, "fullness")
	if not full then
		return "This food is unknown and could potentially be larger than your remaining turns of Got Milk.", "eating unknown food", "OK, disable the warning."
	else
		local need_turns = quantity * full
		if buffturns("Got Milk") < need_turns then
			return "You do not have enough turns of Got Milk active (need " .. need_turns .. ")", "eating without enough turns of got milk"
		end
	end
end

add_aftercore_warning("/inv_eat.php", function()
	return check_eating_warning(tonumber(params.whichitem), (tonumber(params.quantity) or 1))
end)

add_extra_ascension_warning("/inv_eat.php", function()
	if have("milk of magnesium") or (have("glass of goat's milk") and (have("scrumptious reagent") or classid() == 4 or have_skill("Advanced Saucecrafting"))) then
		return check_eating_warning(tonumber(params.whichitem), (tonumber(params.quantity) or 1))
	end
end)
